==> open-xchange-saml-core_7.10.1.orig.tar.bz2: open-xchange-saml-core-7.10.1/com.openexchange.saml/src/com/openexchange/saml/spi/CredentialProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.saml.spi;

import java.util.List;
import org.opensaml.xml.security.credential.Credential;


/**
 * An implementation of this interface is used at runtime to obtain {@link Credential} instances
 * that are used for signing/decryption and signature validation of SAML objects.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @since v7.6.1
 * @see KeyStoreCredentialProvider
 * @see KeySpecCredentialProvider
 */
public interface CredentialProvider {

    /**
     * Checks if this provider contains a credential list to validate the signatures of digitally signed SAML objects that have been
     * received from the IDP.
     *
     * @return <code>true</code> if {@link #getValidationCredentials()} returns a valid credential
     */
    boolean hasValidationCredentials();

    /**
     * Gets the credential list that can be used to validate the signatures of digitally signed SAML objects that have been
     * received from the IDP.
     *
     * @return The List of credentials or an empty list if none are available
     */
    List<Credential> getValidationCredentials();
    
    /**
     * Checks if this provider contains a credential to sign SAML objects that are to be sent to the IDP.
     *
     * @return <code>true</code> if {@link #getSigningCredential()} returns a valid credential
     */
    boolean hasSigningCredential();

    /**
     * Gets the credential used for signing SAML objects that are to be sent to the IDP.
     *
     * @return The credential or <code>null</code> if none is available
     */
    Credential getSigningCredential();

    /**
     * Checks if this provider contains a credential to decrypt encrypted SAML objects or according key encryption keys that have
     * been received from the IDP.
     *
     * @return <code>true</code> if {@link #getDecryptionCredential()} returns a valid credential
     */
    boolean hasDecryptionCredential();

    /**
     * Gets the credential used to decrypt encrypted SAML objects or according key encryption keys that have
     * been received from the IDP.
     *
     * @return The credential or <code>null</code> if none is available
     */
    Credential getDecryptionCredential();

}

==> open-xchange-saml-core_7.10.2.orig.tar.bz2: open-xchange-saml-core-7.10.2/com.openexchange.saml/src/com/openexchange/saml/spi/CredentialProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.saml.spi;

import java.util.List;
import org.opensaml.xml.security.credential.Credential;


/**
 * An implementation of this interface is used at runtime to obtain {@link Credential} instances
 * that are used for signing/decryption and signature validation of SAML objects.
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 * @since v7.6.1
 * @see KeyStoreCredentialProvider
 * @see KeySpecCredentialProvider
 */
public interface CredentialProvider {

    /**
     * Checks if this provider contains a credential to validate the signatures of digitally signed SAML objects that have been
     * received from the IDP.
     *
     * @return <code>true</code> if {@link #getValidationCredential()} returns a valid credential
     * @deprecated Use {@link CredentialProvider#hasValidationCredentials} instead
     */
    @Deprecated
    boolean hasValidationCredential();

    /**
     * Gets the credential that can be used to validate the signatures of digitally signed SAML objects that have been
     * received from the IDP.
     *
     * @return The credential or <code>null</code> if none is available
     * @deprecated Use {@link CredentialProvider#getValidationCredentials} instead
     */
    @Deprecated
    Credential getValidationCredential();
    
    /**
     * Checks if this provider contains a credential list to validate the signatures of digitally signed SAML objects that have been
     * received from the IDP.
     *
     * @return <code>true</code> if {@link #getValidationCredentials()} returns a valid credential
     */
    boolean hasValidationCredentials();

    /**
     * Gets the credential list that can be used to validate the signatures of digitally signed SAML objects that have been
     * received from the IDP.
     *
     * @return The List of credentials or an empty list if none are available
     */
    List<Credential> getValidationCredentials();
    
    /**
     * Checks if this provider contains a credential to sign SAML objects that are to be sent to the IDP.
     *
     * @return <code>true</code> if {@link #getSigningCredential()} returns a valid credential
     */
    boolean hasSigningCredential();

    /**
     * Gets the credential used for signing SAML objects that are to be sent to the IDP.
     *
     * @return The credential or <code>null</code> if none is available
     */
    Credential getSigningCredential();

    /**
     * Checks if this provider contains a credential to decrypt encrypted SAML objects or according key encryption keys that have
     * been received from the IDP.
     *
     * @return <code>true</code> if {@link #getDecryptionCredential()} returns a valid credential
     */
    boolean hasDecryptionCredential();

    /**
     * Gets the credential used to decrypt encrypted SAML objects or according key encryption keys that have
     * been received from the IDP.
     *
     * @return The credential or <code>null</code> if none is available
     */
    Credential getDecryptionCredential();

}
